==> sqlite_database-0.4.1.tar.gz: sqlite_database-0.4.1/README.md <==
# SQLite Database

<div align="center">

![GitHub forks](https://img.shields.io/github/forks/RimuEirnarn/sqlite_database?style=social)
![GitHub Repo stars](https://img.shields.io/github/stars/RimuEirnarn/sqlite_database?style=social)

![GitHub closed issues](https://img.shields.io/github/issues-closed-raw/RimuEirnarn/sqlite_database)
![GitHub closed pull requests](https://img.shields.io/github/issues-pr-closed/RimuEirnarn/sqlite_database)
![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/RimuEirnarn/sqlite_database)
![Lines of code](https://img.shields.io/tokei/lines/github/RimuEirnarn/sqlite_database)
![GitHub all releases](https://img.shields.io/github/downloads/RimuEirnarn/sqlite_database/total)
![GitHub Workflow(pylint) Status](https://img.shields.io/github/actions/workflow/status/RimuEirnarn/sqlite_database/pylint.yml?label=lint)
![GitHub Workflow(pytest) Status](https://img.shields.io/github/actions/workflow/status/RimuEirnarn/sqlite_database/python-app.yml?label=tests)
![GitHub Workflow(pypi) Status](https://img.shields.io/github/actions/workflow/status/RimuEirnarn/sqlite_database/python-publish.yml)
![GitHub release (latest by date)](https://img.shields.io/github/v/release/RimuEirnarn/sqlite_database)
[![Documentation Status](https://readthedocs.org/projects/sqlite-database/badge/?version=latest)](https://sqlite-database.readthedocs.io/en/latest/?badge=latest)
![GitHub](https://img.shields.io/github/license/RimuEirnarn/sqlite_database)
    
![PyPI - Format](https://img.shields.io/pypi/format/sqlite-database)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/sqlite-database)
![PyPI - Implementation](https://img.shields.io/pypi/implementation/sqlite-database)
![PyPI - Downloads](https://img.shields.io/pypi/dm/sqlite-database?label=%28PyPI%29%20downloads)

</div>

SQLite Database is a weird wrapper for SQLite Connection. It's intended to be easy to use and simple.

I will (always) try to bring more simplifications and others that could be done with SQL in general.

## Installation

Installation from PyPI is now available, `pip install sqlite-database`

From previous versions, installations can be done using `https://github.com/RimuEirnarn/sqlite_database/archive/refs/tags/<latest version>.zip`

## Features

Feature overview can be found in [Features.md](https://github.com/RimuEirnarn/sqlite_database/blob/main/Features.md)

## History & Pre-contributors

You can read why this library exists by reading [the history](History.md). The pre-contributor is only ChatGPT.

## Contributing

You can submit any issue if you found a good issue. You can submit a pull request as long as the thing you want complies with what this project aims for.

## License

This library/wrapper/repo/project is licensed with/in BSD 3-Clause "New" or "Revised" License.

[LICENSE](https://github.com/RimuEirnarn/sqlite_database/blob/main/LICENSE)

==> sqlite_database-0.5.5.tar.gz: sqlite_database-0.5.5/README.md <==
# SQLite Database

<div align="center">

![GitHub forks](https://img.shields.io/github/forks/RimuEirnarn/sqlite_database?style=social)
![GitHub Repo stars](https://img.shields.io/github/stars/RimuEirnarn/sqlite_database?style=social)

![GitHub closed issues](https://img.shields.io/github/issues-closed-raw/RimuEirnarn/sqlite_database)
![GitHub closed pull requests](https://img.shields.io/github/issues-pr-closed/RimuEirnarn/sqlite_database)
![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/RimuEirnarn/sqlite_database)
![Lines of code](https://img.shields.io/tokei/lines/github/RimuEirnarn/sqlite_database)
![GitHub all releases](https://img.shields.io/github/downloads/RimuEirnarn/sqlite_database/total)
![GitHub Workflow(pylint) Status](https://img.shields.io/github/actions/workflow/status/RimuEirnarn/sqlite_database/pylint.yml?label=lint)
![GitHub Workflow(pytest) Status](https://img.shields.io/github/actions/workflow/status/RimuEirnarn/sqlite_database/python-app.yml?label=tests)
![GitHub Workflow(pypi) Status](https://img.shields.io/github/actions/workflow/status/RimuEirnarn/sqlite_database/python-publish.yml)
![GitHub release (latest by date)](https://img.shields.io/github/v/release/RimuEirnarn/sqlite_database)
[![Documentation Status](https://readthedocs.org/projects/sqlite-database/badge/?version=latest)](https://sqlite-database.readthedocs.io/en/latest/?badge=latest)
![GitHub](https://img.shields.io/github/license/RimuEirnarn/sqlite_database)
    
![PyPI - Format](https://img.shields.io/pypi/format/sqlite-database)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/sqlite-database)
![PyPI - Implementation](https://img.shields.io/pypi/implementation/sqlite-database)
![PyPI - Downloads](https://img.shields.io/pypi/dm/sqlite-database?label=%28PyPI%29%20downloads)

</div>

SQLite Database is a weird wrapper for SQLite Connection. It's intended to be easy to use and simple.

> [!WARNING]
> This project as per version number (<1.0) is not either efficient (in term of memory usage) and fast. If you found a serious problem, please let us know.

## Installation

Installation from PyPI is now available, `pip install sqlite-database`

From previous versions, installations can be done using `pip install https://github.com/RimuEirnarn/sqlite_database/archive/refs/tags/<latest version>.zip`

## Features

Feature overview can be found in [Features.md](https://github.com/RimuEirnarn/sqlite_database/blob/main/Features.md)

It's still recommended to see the [short docs](https://sqlite-database.rtfd.io/)

## History & Pre-contributors

You can read why this library exists by reading [the history](History.md). The pre-contributor is only ChatGPT.

## Contributing

You can submit any issue if you found a good issue. You can submit a pull request as long as the thing you want complies with what this project aims for.

## License

This library/wrapper/repo/project is licensed with/in BSD 3-Clause "New" or "Revised" License.

[LICENSE](https://github.com/RimuEirnarn/sqlite_database/blob/main/LICENSE)
